@@ -2,7 +2,7 @@ import fnmatch
 import logging
 import time
 from pathlib import Path
-from typing import List
+from typing import List, Union
 
 import zarr
 import dask
